==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailTemplateResponseEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EmailSettingsResponse;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailTemplateResponseEmbedded
 */
@JsonPropertyOrder({ EmailTemplateResponseEmbedded.JSON_PROPERTY_SETTINGS,
        EmailTemplateResponseEmbedded.JSON_PROPERTY_CUSTOMIZATION_COUNT })
@JsonTypeName("EmailTemplateResponse__embedded")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailTemplateResponseEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SETTINGS = "settings";
    private EmailSettingsResponse settings;

    public static final String JSON_PROPERTY_CUSTOMIZATION_COUNT = "customizationCount";
    private Integer customizationCount;

    public EmailTemplateResponseEmbedded() {
    }

    public EmailTemplateResponseEmbedded settings(EmailSettingsResponse settings) {

        this.settings = settings;
        return this;
    }

    /**
     * Get settings
     *
     * @return settings
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EmailSettingsResponse getSettings() {
        return settings;
    }

    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSettings(EmailSettingsResponse settings) {
        this.settings = settings;
    }

    public EmailTemplateResponseEmbedded customizationCount(Integer customizationCount) {

        this.customizationCount = customizationCount;
        return this;
    }

    /**
     * Get customizationCount
     *
     * @return customizationCount
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZATION_COUNT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getCustomizationCount() {
        return customizationCount;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZATION_COUNT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizationCount(Integer customizationCount) {
        this.customizationCount = customizationCount;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailTemplateResponseEmbedded emailTemplateResponseEmbedded = (EmailTemplateResponseEmbedded) o;
        return Objects.equals(this.settings, emailTemplateResponseEmbedded.settings)
                && Objects.equals(this.customizationCount, emailTemplateResponseEmbedded.customizationCount);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(settings, customizationCount);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailTemplateResponseEmbedded {\n");
        sb.append("    settings: ").append(toIndentedString(settings)).append("\n");
        sb.append("    customizationCount: ").append(toIndentedString(customizationCount)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailTemplateResponseEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EmailSettingsResponse;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailTemplateResponseEmbedded
 */
@JsonPropertyOrder({ EmailTemplateResponseEmbedded.JSON_PROPERTY_SETTINGS,
        EmailTemplateResponseEmbedded.JSON_PROPERTY_CUSTOMIZATION_COUNT })
@JsonTypeName("EmailTemplateResponse__embedded")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailTemplateResponseEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SETTINGS = "settings";
    private EmailSettingsResponse settings;

    public static final String JSON_PROPERTY_CUSTOMIZATION_COUNT = "customizationCount";
    private Integer customizationCount;

    public EmailTemplateResponseEmbedded() {
    }

    public EmailTemplateResponseEmbedded settings(EmailSettingsResponse settings) {

        this.settings = settings;
        return this;
    }

    /**
     * Get settings
     *
     * @return settings
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EmailSettingsResponse getSettings() {
        return settings;
    }

    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSettings(EmailSettingsResponse settings) {
        this.settings = settings;
    }

    public EmailTemplateResponseEmbedded customizationCount(Integer customizationCount) {

        this.customizationCount = customizationCount;
        return this;
    }

    /**
     * Get customizationCount
     *
     * @return customizationCount
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZATION_COUNT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getCustomizationCount() {
        return customizationCount;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZATION_COUNT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizationCount(Integer customizationCount) {
        this.customizationCount = customizationCount;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailTemplateResponseEmbedded emailTemplateResponseEmbedded = (EmailTemplateResponseEmbedded) o;
        return Objects.equals(this.settings, emailTemplateResponseEmbedded.settings)
                && Objects.equals(this.customizationCount, emailTemplateResponseEmbedded.customizationCount);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(settings, customizationCount);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailTemplateResponseEmbedded {\n");
        sb.append("    settings: ").append(toIndentedString(settings)).append("\n");
        sb.append("    customizationCount: ").append(toIndentedString(customizationCount)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
